@@ -84,7 +84,7 @@ def get_results_for_a_specific_scan_id_with_query_language_state(scan_id, filter
     # have to put ScanId in url, otherwise would have deserialization error
     url = ("/Cxwebinterface/odata/v1/Scans({id})/Results?$select=Id,ScanId,QueryId,SimilarityId"
            "&$expand=Query($select=Name;$expand=QueryGroup($select=Name,"
-           "LanguageName)),State($select=Name),Scan($select=Origin)").format(
+           "LanguageName)),State($select=Name),Scan($select=Origin,LOC)").format(
         id=scan_id
     )
 
@@ -103,6 +103,7 @@ def get_results_for_a_specific_scan_id_with_query_language_state(scan_id, filter
             "ResultId": item.get("Id"),
             "ResultState": item.get("State").get("Name"),
             "Origin": item.get("Scan").get("Origin"),
+            "LOC": item.get("Scan").get("LOC"),
         } for item in item_list
     ]
 
