@@ -16,4 +16,4 @@ class CxCreateProjectResponse(object):
         self.link = link
 
     def __str__(self):
-        return "CxCreateProjectResponse(project_id={}, link={})".format(self.id, self.link)
+        return "CxCreateProjectResponse(id={}, link={})".format(self.id, self.link)
