@@ -16,7 +16,7 @@ class CxProjectQueueSetting(object):
         self.identical_code_only = identical_code_only
 
     def __str__(self):
-        return """CxProjectQueueSetting(queue_keep_mode={}, scans_type={}}, include_scans_in_process={}, 
-                 identical_code_only={}})""".format(
+        return """CxProjectQueueSetting(queue_keep_mode={}, scans_type={}, include_scans_in_process={},
+                 identical_code_only={})""".format(
             self.queue_keep_mode, self.scans_type, self.include_scans_in_process, self.identical_code_only
         )
